@@ -233,8 +233,16 @@ hook_r2swf = function(x, options) {
 render_html = function() {
   set_html_dev()
   opts_knit$set(out.format = 'html')
+  h = opts_knit$get('header')
+  if (!nzchar(h['highlight'])) set_header(highlight = .header.hi.html)
+  knit_hooks$set(hooks_html())
+}
+
+#' @rdname output_hooks
+#' @export
+hooks_html = function() {
   # use div with different classes
-  html.hook = function(name) {
+  hook = function(name) {
     force(name)
     function(x, options) {
       x = if (name == 'source') {
@@ -244,14 +252,12 @@ render_html = function() {
       sprintf('<div class="%s"><pre class="knitr %s">%s</pre></div>\n', name, tolower(options$engine), x)
     }
   }
-  h = opts_knit$get('header')
-  if (!nzchar(h['highlight'])) set_header(highlight = .header.hi.html)
-  z = list()
-  for (i in c('source', 'warning', 'message', 'error'))
-    z[[i]] = html.hook(i)
-  knit_hooks$set(z)
-  knit_hooks$set(inline = function(x) {
-    sprintf(if (inherits(x, 'AsIs')) '%s' else '<code class="knitr inline">%s</code>',
-            .inline.hook(format_sci(x, 'html')))
-  }, output = html.hook('output'), plot = hook_plot_html, chunk = .chunk.hook.html)
+  list(
+    source = hook('source'), output = hook('output'), warning = hook('warning'),
+    message = hook('message'), error = hook('error'), plot = hook_plot_html,
+    chunk = .chunk.hook.html, inline = function(x) sprintf(
+      if (inherits(x, 'AsIs')) '%s' else '<code class="knitr inline">%s</code>',
+      .inline.hook(format_sci(x, 'html'))
+    )
+  )
 }
