@@ -7,9 +7,7 @@ hook_plot_md = function(x, options) {
   if ((options$fig.show == 'animate' || is_tikz_dev(options)) && is_latex_output())
     return(hook_plot_tex(x, options))
   office_output = to %in% c('docx', 'pptx', 'rtf', 'odt')
-  if (!is.null(options$out.width) || !is.null(options$out.height) ||
-      !is.null(options$out.extra) || options$fig.align != 'default' ||
-      !is.null(options$fig.subcap) || options$fig.env != 'figure') {
+  if (need_special_plot_hook(options)) {
     if (is_latex_output()) {
       # Pandoc < 1.13 does not support \caption[]{} so suppress short caption
       if (is.null(options$fig.scap)) options$fig.scap = NA
@@ -26,6 +24,17 @@ hook_plot_md = function(x, options) {
   hook_plot_md_base(x, options)
 }
 
+# decide if the markdown plot hook is not enough and needs special hooks like
+# hook_plot_tex() to handle chunk options like out.width
+need_special_plot_hook = function(options) {
+  opts = opts_chunk$get(default = TRUE)
+  for (i in c(
+    'out.width', 'out.height', 'out.extra',
+    'fig.align', 'fig.subcap', 'fig.env', 'fig.scap'
+  )) if (!identical(options[[i]], opts[[i]])) return(TRUE)
+  FALSE
+}
+
 hook_plot_md_base = function(x, options) {
   if (options$fig.show == 'animate') return(hook_plot_html(x, options))
 
@@ -41,10 +50,11 @@ hook_plot_md_base = function(x, options) {
   in_bookdown = isTRUE(opts_knit$get('bookdown.internal.label'))
   plot1 = ai || options$fig.cur <= 1L
   plot2 = ai || options$fig.cur == options$fig.num
+  to = pandoc_to(); from = pandoc_from()
   if (is.null(w) && is.null(h) && is.null(s) && a == 'default' && !(pandoc_html && in_bookdown)) {
     # append <!-- --> to ![]() to prevent the figure environment in these cases
-    nocap = cap == '' && !is.null(to <- pandoc_to()) && !grepl('^markdown', to) &&
-      (options$fig.num == 1 || ai) && !grepl('-implicit_figures', pandoc_from())
+    nocap = cap == '' && !is.null(to) && !grepl('^markdown', to) &&
+      (options$fig.num == 1 || ai) && !grepl('-implicit_figures', from)
     res = sprintf('![%s](%s%s)', cap, base, .upload.url(x))
     if (!is.null(lnk) && !is.na(lnk)) res = sprintf('[%s](%s)', res, lnk)
     res = paste0(res, if (nocap) '<!-- -->' else '', if (is_latex_output()) ' ' else '')
@@ -55,7 +65,7 @@ hook_plot_md_base = function(x, options) {
     sprintf('<a href="%s" target="_blank">%s</a>', lnk, x)
   }
   # use HTML syntax <img src=...>
-  if (pandoc_html) {
+  if (pandoc_html && !isTRUE(grepl('-implicit_figures', from))) {
     d1 = if (plot1) sprintf('<div class="figure"%s>\n', css_text_align(a))
     d2 = sprintf('<p class="caption">%s</p>', cap)
     img = sprintf(
@@ -130,6 +140,12 @@ block_attr = function(attr, class = NULL, lang = NULL) {
 render_markdown = function(strict = FALSE, fence_char = '`') {
   set_html_dev()
   opts_knit$set(out.format = 'markdown')
+  knit_hooks$set(hooks_markdown(strict, fence_char))
+}
+
+#' @rdname output_hooks
+#' @export
+hooks_markdown = function(strict = FALSE, fence_char = '`') {
   fence = paste(rep(fence_char, 3), collapse = '')
   # four spaces lead to <pre></pre>
   hook.t = function(x, options, attr = NULL, class = NULL) {
@@ -160,10 +176,7 @@ render_markdown = function(strict = FALSE, fence_char = '`') {
     attrs = block_attr(options$attr.source, options$class.source, language)
     paste0('\n\n', fence, attrs, '\n', x, fence, '\n\n')
   }
-  hooks = list()
-  for (i in c('output', 'warning', 'error', 'message')) hooks[[i]] = hook.o(i)
-  knit_hooks$set(hooks)
-  knit_hooks$set(
+  list(
     source = function(x, options) {
       x = hilight_source(x, 'markdown', options)
       (if (strict) hook.t else hook.r)(one_string(c(x, '')), options)
@@ -183,9 +196,12 @@ render_markdown = function(strict = FALSE, fence_char = '`') {
       }
       if (is.null(s <- options$indent)) return(x)
       line_prompt(x, prompt = s, continue = s)
-    }
+    },
+    output = hook.o('output'), warning = hook.o('warning'),
+    error = hook.o('error'), message = hook.o('message')
   )
 }
+
 #' @param highlight Which code highlighting engine to use: if \code{pygments},
 #'   the Liquid syntax is used (default approach Jekyll); if \code{prettify},
 #'   the output is prepared for the JavaScript library \file{prettify.js}; if
@@ -196,9 +212,16 @@ render_markdown = function(strict = FALSE, fence_char = '`') {
 #' @rdname output_hooks
 #' @export
 render_jekyll = function(highlight = c('pygments', 'prettify', 'none'), extra = '') {
-  hi = match.arg(highlight)
   render_markdown(TRUE)
-  if (hi == 'none') return()
+  knit_hooks$set(hooks_jekyll(highlight = highlight, extra = extra))
+}
+
+#' @rdname output_hooks
+#' @export
+hooks_jekyll = function(highlight = c('pygments', 'prettify', 'none'), extra = '') {
+  hook.m = hooks_markdown(TRUE)
+  hi = match.arg(highlight)
+  if (hi == 'none') return(hook.m)
   switch(hi, pygments = {
     hook.r = function(x, options) {
       paste0(
@@ -220,8 +243,11 @@ render_jekyll = function(highlight = c('pygments', 'prettify', 'none'), extra =
       '\n\n<pre><code>', escape_html(x), '</code></pre>\n\n'
     )
   })
-  knit_hooks$set(source = function(x, options) {
+  source = function(x, options) {
     x = one_string(hilight_source(x, 'markdown', options))
     hook.r(x, options)
-  }, output = hook.t, warning = hook.t, error = hook.t, message = hook.t)
+  }
+  merge_list(hook.m, list(
+    source = source, output = hook.t, warning = hook.t, message = hook.t, error = hook.t
+  ))
 }
