@@ -2,7 +2,7 @@
 #'
 #' Since R 3.0.0, package vignettes can use non-Sweave engines, and \pkg{knitr}
 #' has provided a few engines to compile vignettes via \code{\link{knit}()} with
-#' different templates. See \url{https://yihui.name/knitr/demo/vignette/} for
+#' different templates. See \url{https://yihui.org/knitr/demo/vignette/} for
 #' more information.
 #' @name vignette_engines
 #' @note If you use the \code{knitr::rmarkdown} engine, please make sure that
@@ -65,7 +65,8 @@ body(vweave_docco_classic)[5L] = expression(rocco(
 
 vweave_rmarkdown = vweave
 body(vweave_rmarkdown)[5L] = expression(rmarkdown::render(
-  file, encoding = encoding, quiet = quiet, envir = globalenv(), ...
+  file, encoding = encoding, quiet = quiet, envir = globalenv(),
+  output_dir = getwd(), ...
 ))
 
 # do not tangle R code from vignettes
@@ -99,8 +100,12 @@ register_vignette_engines = function(pkg) {
       vweave(...)
     }
   } else {
-    warning('The vignette engine knitr::rmarkdown is not available, ',
-            'because the rmarkdown package is not installed. Please install it.')
+    # TODO: no longer allow fallback to R Markdown v1
+    (if (is_CRAN_incoming()) stop2 else warning)(
+      'The vignette engine knitr::rmarkdown is not available because the rmarkdown ',
+      'package is not available. Did you forget to add it to Suggests in DESCRIPTION? ',
+      'Please see https://github.com/yihui/knitr/issues/1864 for more information.'
+    )
     vweave(...)
   }, '[.][Rr](md|markdown)$')
   # vignette engines that disable tangle
